@@ -242,6 +242,9 @@ fsusage_update (GTopFsUsageData *d)
 	glong selected_fs_mask;
 	gint selected_fs;
 
+	if (!d->graph)
+		return FALSE;
+
 	if (mount_list)
 		glibtop_free (mount_list);
 
@@ -367,7 +370,7 @@ fsusage_update (GTopFsUsageData *d)
 
 	if (fsusage_data) {
 		for (i = 0; i < fsusage_number; i++)
-			glibtop_free ((fsusage_data+i)->cmd);
+			g_free ((fsusage_data+i)->cmd);
 		g_free (fsusage_data);
 	}
 
