@@ -9,11 +9,11 @@ GdkColor graph_default_colors [GRAPH_DEFAULT_COLORS] = {
 };
 
 static const gchar *default_fonts [5] = {
+	"-*-courier-medium-r-*-*-10-*-*-*-m-*-*-*",
 	"-*-courier-medium-r-*-*-12-*-*-*-m-*-*-*",
 	"-*-courier-medium-r-*-*-14-*-*-*-m-*-*-*",
 	"-*-courier-medium-r-*-*-18-*-*-*-m-*-*-*",
-	"-*-courier-medium-r-*-*-24-*-*-*-m-*-*-*",
-	"-*-courier-medium-r-*-*-34-*-*-*-m-*-*-*"
+	"-*-courier-medium-r-*-*-24-*-*-*-m-*-*-*"
 };
 
 static void	graph_expose (GtkWidget *, GdkEventExpose *, Graph *);
@@ -28,8 +28,6 @@ static void	graph_properties_save (GnomePropertyObject *);
 
 static void	graph_properties_changed (GnomePropertyObject *);
 
-static gint	graph_font_apply (GtkFontSelectionDialog *);
-
 static void	graph_colors_set (Graph *);
 
 GnomePropertyDescriptor GraphProperty_Descriptor = {
@@ -164,7 +162,7 @@ graph_process_data (Graph *g)
 {
 	gint w ,h, draw;
 	gpointer data;
-	unsigned value, total;
+	unsigned total;
 	gint ll, mll = 0;
 	gint th, gh=0, cgh;
 	gint i, c = 0;
@@ -456,12 +454,6 @@ graph_properties_update (GnomePropertyObject *object)
 	}
 }
 
-static void
-color_changed_cb (void)
-{
-	gtop_properties_changed ();
-}          
-
 static void
 adjustment_changed_cb (GtkWidget *widget,
 		       GtkWidget *adjustment)
@@ -473,8 +465,6 @@ static void
 graph_properties_apply (GnomePropertyObject *object)
 {
 	GTopGraphProperties *prop_ptr = object->temp_data;
-	GdkColor *color;
-	gushort i, r, g, b, a;
 
 	prop_ptr->default_width =
 		adjustments [DEFAULT_WIDTH]->value;
@@ -511,8 +501,7 @@ static GtkWidget *
 graph_properties_init (GnomePropertyObject *object)
 {
 	GTopGraphProperties *prop_ptr = &gtop_properties.graph;
-	GtkWidget *vb, *frame, *table, *label, *button, *entry, *spin, *cp;
-	RadioButtonCbData *cb_data;
+	GtkWidget *vb, *frame, *table, *label, *spin;
 	GtkObject *adjustment;
 	int i;
 
@@ -737,8 +726,15 @@ graph_properties_load (GnomePropertyObject *object)
 		gtop_properties.graph.font = gdk_font_load
 			(gtop_properties.graph.font_name);
 
-	width = (gfloat) gdk_screen_width () * 0.875;
-	height = (gfloat) gdk_screen_height () * 0.70;
+	if (!gtop_properties.graph.font) {
+		g_free (gtop_properties.graph.font_name);
+		gtop_properties.graph.font_name = g_strdup (default_font);
+		gtop_properties.graph.font = gdk_font_load
+			(gtop_properties.graph.font_name);
+	}
+
+	width = (gfloat) gdk_screen_width () * 0.60;
+	height = (gfloat) gdk_screen_height () * 0.40;
 
 	sprintf (name, "gtop/graph/default_width=%d", width);
 	gtop_properties.graph.default_width = gnome_config_get_int (name);
@@ -759,7 +755,7 @@ graph_properties_load (GnomePropertyObject *object)
 		gnome_config_get_int ("gtop/graph/pad_width=20");
 
 	gtop_properties.graph.graph_width =
-		gnome_config_get_int ("gtop/graph/graph_width=100");
+		gnome_config_get_int ("gtop/graph/graph_width=80");
 
 	gtop_properties.graph.extra_height =
 		gnome_config_get_int ("gtop/graph/extra_height=0");
