@@ -52,25 +52,12 @@ enum {
 	LAST_SIGNAL
 };
 
-static gint gtop_fsusage_signals [LAST_SIGNAL];
+static gint gtop_fsusage_signals [(int)LAST_SIGNAL + 1];
 
 typedef void (*GTopFsUsageSignal) (GtkObject *, gpointer, gpointer);
 
 static GtkScrolledWindowClass *parent_class = NULL;
 
-static void 
-gtop_fsusage_marshal (GtkObject		*object,
-		      GtkSignalFunc	func,
-		      gpointer		func_data,
-		      GtkArg		*args)
-{
-	GTopFsUsageSignal rfunc;
-	
-	rfunc = (GTopFsUsageSignal) func;
-
-	(* rfunc)(object, GTK_VALUE_POINTER(args[0]), func_data);
-}
-
 guint
 gtop_fsusage_get_type ()
 {
@@ -209,6 +196,8 @@ gtop_fsusage_type_set (GTopFsUsage *fsusage, gint ftype)
 			(GNOME_MDI_CHILD (fsusage->page), label);
 
 	fsusage_type_set (&fsusage->data, ftype);
+
+	fsusage_update (&fsusage->data);
 }
 
 static void
