@@ -62,25 +62,12 @@ enum {
 	LAST_SIGNAL
 };
 
-static gint gtop_memusage_signals [LAST_SIGNAL];
+static gint gtop_memusage_signals [(int)LAST_SIGNAL + 1];
 
 typedef void (*GTopMemUsageSignal) (GtkObject *, gpointer, gpointer);
 
 static GtkScrolledWindowClass *parent_class = NULL;
 
-static void 
-gtop_memusage_marshal (GtkObject		*object,
-		      GtkSignalFunc	func,
-		      gpointer		func_data,
-		      GtkArg		*args)
-{
-	GTopMemUsageSignal rfunc;
-	
-	rfunc = (GTopMemUsageSignal) func;
-
-	(* rfunc)(object, GTK_VALUE_POINTER(args[0]), func_data);
-}
-
 guint
 gtop_memusage_get_type ()
 {
@@ -226,6 +213,8 @@ gtop_memusage_type_set (GTopMemUsage *memusage, gint ftype)
 			(GNOME_MDI_CHILD (memusage->page), label);
 
 	memusage_type_set (&memusage->data, ftype);
+
+	memusage_update (&memusage->data);
 }
 
 static void
