@@ -5,8 +5,7 @@
 #include <gtop-memusage.h>
 #include <gtop-procview.h>
 
-#include <summary.h>
-
+#include <details.h>
 #include <session.h>
 
 #include <string.h>
@@ -25,7 +24,6 @@ static void	reap_viewless_childs	(void);
 static void	add_view_cb		(void);
 static void	add_toplevel_cb		(void);
 static void	remove_view_cb		(void);
-static void	remove_child_cb		(void);
 
 GnomeUIInfo fileMenu [] = {
 	GNOMEUIINFO_MENU_NEW_ITEM
@@ -203,13 +201,6 @@ remove_view_cb (void)
 	reap_viewless_childs ();
 }
 
-static void
-remove_child_cb (void)
-{
-	GnomeMDIChild *child = gnome_mdi_get_active_child (mdi);
-	if (child) gnome_mdi_remove_child (mdi, child, FALSE);
-}
-
 static void
 view_changed_cb (GnomeMDI *mdi, GtkWidget *old_view)
 {
@@ -262,6 +253,21 @@ app_destroy_cb (GnomeApp *app, GTopStatusBarData *d)
 	gtop_statusbar_destroy (d);
 }
 
+static void
+drag_data_received (GtkWidget *widget, GdkDragContext *context,
+		    gint x, gint y, GtkSelectionData *data,
+		    guint info, guint32 time)
+{
+    if (data->format == 1) {
+	    GnomeMDIChild *child = gtop_page_create_from_config (data->data);
+		
+	    gnome_mdi_add_child (mdi, child);
+	    gnome_mdi_add_view (mdi, child);
+    }
+
+    gtk_drag_finish (context, FALSE, FALSE, time);
+}
+
 static void
 app_created_cb (GnomeMDI *mdi, GnomeApp *app)
 {
@@ -273,9 +279,17 @@ app_created_cb (GnomeMDI *mdi, GnomeApp *app)
 	gnome_app_set_statusbar_custom (app, d->container, d->status_bar);
         gnome_app_install_menu_hints (app, gnome_mdi_get_menubar_info (app));
 
+	gtk_signal_connect (GTK_OBJECT (app), "drag_data_received",
+			    GTK_SIGNAL_FUNC (drag_data_received), NULL);
+
+	gtk_drag_dest_set (GTK_WIDGET (app),
+			   GTK_DEST_DEFAULT_ALL,
+			   gtop_target_table, 1,
+			   GDK_ACTION_COPY | GDK_ACTION_MOVE);
+
 	gtk_signal_connect (GTK_OBJECT (app), "destroy",
 			    GTK_SIGNAL_FUNC (app_destroy_cb), d);
-};
+}
 
 void
 gtop_mdi_init (void)
@@ -289,7 +303,6 @@ gtop_mdi_start (gboolean init)
 {
 	GTopPage *page;
 	GtkWidget *view;
-	GtkWidget *window;
 
 	gtk_signal_connect(GTK_OBJECT (mdi), "view_changed",
 			   GTK_SIGNAL_FUNC (view_changed_cb), NULL);
@@ -316,13 +329,11 @@ gtop_mdi_start (gboolean init)
 	gnome_mdi_set_active_view (mdi, view);
 
 	if (initial_geometry) {
-		window = GTK_WIDGET (mdi->active_window);
-
-		gtk_widget_set_usize (window,
+		gtk_widget_set_usize (GTK_WIDGET (mdi->active_window),
 				      initial_geometry->width,
 				      initial_geometry->height);
 
-		gtk_widget_set_uposition (window,
+		gtk_widget_set_uposition (GTK_WIDGET (mdi->active_window),
 					  initial_geometry->x,
 					  initial_geometry->y);
 	}
