@@ -185,6 +185,9 @@ memusage_update (GTopMemUsageData *d)
 	static gchar bts [256];
 	glibtop_proclist proclist;
 
+	if (!d->graph)
+		return FALSE;
+
 	if (proc_tab)
 		glibtop_free (proc_tab);
 
@@ -329,7 +332,7 @@ memusage_update (GTopMemUsageData *d)
 	}
 
 	for (i=0; i<n; i++)
-		g_free (ti [i].cmd);
+		glibtop_free (ti [i].cmd);
 
 	g_free (ti);
 	
