@@ -27,6 +27,7 @@
 #include "fromtop.h"
 #include "proc.h"
 #include "details.h"
+#include "process-details.h"
 #include "global.h"
 
 #include "asc.xpm"
@@ -43,16 +44,17 @@ static gint config_sort_order = 0;
 static gint config_remember_sorting = 1;
 
 static void procview_init (GTopProcViewData *);
+static void procview_open_mem_maps (GTopProcViewData *);
 static void procview_open_details (GTopProcViewData *);
 static void procview_clist_prepare (GTopProcViewData *);
 static void procview_clist_update (GTopProcViewData *);
 
 static const gchar *default_fonts [5] = {
+	"-*-courier-medium-r-*-*-8-*-*-*-m-*-*-*",
 	"-*-courier-medium-r-*-*-10-*-*-*-m-*-*-*",
 	"-*-courier-medium-r-*-*-12-*-*-*-m-*-*-*",
 	"-*-courier-medium-r-*-*-14-*-*-*-m-*-*-*",
-	"-*-courier-medium-r-*-*-18-*-*-*-m-*-*-*",
-	"-*-courier-medium-r-*-*-24-*-*-*-m-*-*-*"
+	"-*-courier-medium-r-*-*-18-*-*-*-m-*-*-*"
 };
 
 static GtkWidget *procview_properties_init (GnomePropertyObject *object);
@@ -191,6 +193,7 @@ static void procview_click_column (GtkCList *, gint, GTopProcViewData *);
 static GtkWidget *procview_clist_menu_prepare (GTopProcViewData *);
 
 static void procview_renice (GTopProcViewData *);
+static void procview_menu_cb_mem_maps (GtkWidget *, GTopProcViewData *);
 static void procview_menu_cb_details (GtkWidget *, GTopProcViewData *);
 static void procview_menu_cb_renice (GtkWidget *, GTopProcViewData *);
 
@@ -295,8 +298,6 @@ procview_unmap (GTopProcViewData *d)
 void
 procview_destroy (GtkWidget *widget)
 {
-	GTopProcViewData *d = &(GTOP_PROCVIEW (widget)->data);
-
 	widget_list = g_list_remove (widget_list, widget);
 }
 
@@ -402,18 +403,31 @@ procview_send_signal (GtkWidget *w, gint s)
 }
 
 static void
-procview_open_details (GTopProcViewData *d)
+procview_open_mem_maps (GTopProcViewData *d)
 {
 	if (d->select_pid != -1)
 		procview_details (d, d->select_pid);
 }
 
+static void
+procview_open_details (GTopProcViewData *d)
+{
+	if (d->select_pid != -1)
+		gtop_process_details (d->select_pid);
+}
+
 static void
 procview_menu_cb_details (GtkWidget *w, GTopProcViewData *d)
 {
 	procview_open_details (d);
 }
 
+static void
+procview_menu_cb_mem_maps (GtkWidget *w, GTopProcViewData *d)
+{
+	procview_open_mem_maps (d);
+}
+
 static void
 procview_menu_cb_renice (GtkWidget *w, GTopProcViewData *d)
 {
@@ -614,6 +628,13 @@ procview_clist_menu_prepare (GTopProcViewData *d)
 	gtk_menu_append (GTK_MENU (menu), mi);
 	gtk_widget_show (mi);
 
+	mi = gtk_menu_item_new_with_label (_("Memory Maps ..."));
+	gtk_signal_connect (GTK_OBJECT (mi), "activate",
+			    GTK_SIGNAL_FUNC (procview_menu_cb_mem_maps),
+			    (gpointer) d);
+	gtk_menu_append (GTK_MENU (menu), mi);
+	gtk_widget_show (mi);
+
 	mi = gtk_menu_item_new_with_label (_("Details ..."));
 	gtk_signal_connect (GTK_OBJECT (mi), "activate",
 			    GTK_SIGNAL_FUNC (procview_menu_cb_details),
@@ -714,8 +735,19 @@ procview_clist_update (GTopProcViewData *d)
 	while (c) {
 		GtkWidget *hb = GTK_BIN (cl->column[i].button)->child;
 		GtkBoxChild *bc = (GtkBoxChild *) GTK_BOX (hb)->children->data;
+		GtkStyle *style;
 
 		gtk_label_set (GTK_LABEL (bc->widget), _(CF->label));
+
+		gtk_widget_ensure_style (bc->widget);
+		style = gtk_style_copy (gtk_widget_get_style (bc->widget));
+
+		gdk_font_unref (style->font);
+		style->font = gtop_properties.procview.font;
+		gdk_font_ref (style->font);
+
+		gtk_widget_set_style (bc->widget, style);
+		gtk_style_unref (style);
 		
 		gtk_clist_set_column_visibility (cl, i, TRUE);
 
@@ -783,7 +815,7 @@ procview_init (GTopProcViewData *d)
 gchar *
 sprint_fmt (ProcProcData *d, p_fmt fmt)
 {
-	proc_t *t = d->p;
+	gtop_proc_t *t = d->p;
 	gchar tmp[256];
 	gchar *rv;
 
@@ -887,8 +919,9 @@ procview_update_clist (GTopProcViewData *d, ProcProcData **pd)
 		}
 		gtk_clist_append (GTK_CLIST (d->clist), text);
 
-		for (k=0; k<j; k++)
+		for (k=0; k<j; k++) {
 			g_free (text [k]);
+		}
 	}
 
 	/* keep old view position - somewhat ughly, but works now */
@@ -928,7 +961,7 @@ procview_update (GTopProcViewData *d)
 
 	unsigned long p_gl_main_mem;
 	ProcProcData *data;
-	proc_t *p;
+	gtop_proc_t *p;
 	gint i, j, n=0;
 	gint p_cl_sum;
 
@@ -978,12 +1011,14 @@ procview_update (GTopProcViewData *d)
 	if (d->proc_data) {
 		for (i = 0; i < d->prev_count; i++) {
 			if ((p = d->proc_data [i]->p)) {
-				g_free (p->cmd);
-				g_free (p->user);
+				glibtop_free (p->cmd);
+				glibtop_free (p->user);
 			}
 			g_free (d->proc_data [i]);
+			d->proc_data [i] = NULL;
 		}
 		g_free (d->proc_data);
+		d->proc_data = NULL;
 	}
 
 	n = proclist.number;
@@ -1102,7 +1137,7 @@ procview_update (GTopProcViewData *d)
 	if (d->details.dwin &&
 	    (gtop_properties.procview.details_flags &
 	     (1 << GTOP_DETAILS_AUTO_UPDATE)))
-		procview_open_details (d);
+		procview_open_mem_maps (d);
 }
 
 static void
@@ -1152,10 +1187,8 @@ static GtkWidget *
 procview_properties_init (GnomePropertyObject *object)
 {
 	GTopProcViewProperties *prop_ptr = &gtop_properties.procview;
-	GtkWidget *vb, *hb1, *frame, *label, *entry, *button, *table, *spin, *hb;
+	GtkWidget *vb, *frame, *label, *table, *hb;
 	RadioButtonCbData *cb_data;
-	GtkObject *adjustment;
-	gint summary_mode;
 
 	vb    = gtk_vbox_new (FALSE, 0);
 	gtk_container_border_width (GTK_CONTAINER (vb), GNOME_PAD_SMALL);
@@ -1286,6 +1319,13 @@ procview_properties_load (GnomePropertyObject *object)
 	gtop_properties.procview.font = gdk_font_load
 		(gtop_properties.procview.font_name);
 
+	if (!gtop_properties.procview.font) {
+		g_free (gtop_properties.procview.font_name);
+		gtop_properties.procview.font_name = g_strdup (default_font);
+		gtop_properties.procview.font = gdk_font_load
+			(gtop_properties.procview.font_name);
+	}
+
 	gtop_properties.procview.details_flags =
 		gnome_config_get_int ("gtop/procview/details_flags=0");
 
@@ -1351,7 +1391,7 @@ static GtkWidget *
 procfields_properties_init (GnomePropertyObject *object)
 {
 	GTopProcFieldsProperties *prop_ptr = &gtop_properties.procfields;
-	GtkWidget *label, *spin, *sw, *viewport, *table;
+	GtkWidget *label, *spin, *sw, *table;
 	GtkObject *adjustment;
 	gint i;
 
