@@ -145,7 +145,7 @@ struct save_hist {
 
 struct _ProcProcData {
 	GTopProcViewData *d;
-	proc_t _p, *p;
+	gtop_proc_t _p, *p;
 
 	gint pcpu;
 	gint pmem;
