@@ -83,7 +83,9 @@ static const GdkColor load_defaults [2] = {
                
 static GtkAdjustment *max_loadavg_adjustment;
 
-#define STATUSBAR_DEFAULT_FONT "-*-courier-medium-r-*-*-14-*-*-*-m-*-*-*"
+#define STATUSBAR_DEFAULT_FONT "-*-courier-medium-r-*-*-12-*-*-*-m-*-*-*"
+
+static void update_font (GtkWidget *widget);
 
 static GtkWidget *summary_properties_init (GnomePropertyObject *object);
 static void summary_properties_apply (GnomePropertyObject *object);
@@ -691,6 +693,12 @@ gtop_statusbar_new (void)
 	gtk_widget_pop_style ();
 	gtk_style_unref (style);
 
+	update_font (GNOME_APPBAR (d->status_bar)->status);
+	update_font (d->status_cpu_label);
+	update_font (d->status_mem_label);
+	update_font (d->status_uptime_label);
+	update_font (d->status_loadavg_label);
+
 	statusbar_object_list = g_list_append (statusbar_object_list, d);
 
 	return d;
@@ -699,8 +707,6 @@ gtop_statusbar_new (void)
 void
 gtop_statusbar_update (GTopStatusBarData *d)
 {
-	gint config_has_swap;
-
 	if (SUMMARY_MODE_BIT (SHOW_TEXT))
 		gtk_widget_show (d->container);
 	else
@@ -877,6 +883,7 @@ summary_properties_update (GnomePropertyObject *object)
 	for (c = statusbar_object_list; c; c = c->next) {
 		GTopStatusBarData *d = c->data;
 
+		update_font (GNOME_APPBAR (d->status_bar)->status);
 		update_font (d->status_cpu_label);
 		update_font (d->status_mem_label);
 		update_font (d->status_uptime_label);
@@ -890,8 +897,7 @@ static GtkWidget *
 summary_properties_init (GnomePropertyObject *object)
 {
 	GTopSummaryProperties *prop_ptr = &gtop_properties.summary;
-	GtkWidget *vb, *hb1, *frame, *label, *entry;
-	GtkWidget *button, *table, *spin, *hb;
+	GtkWidget *vb, *hb1, *frame, *label, *table, *spin, *hb;
 	RadioButtonCbData *cb_data;
 	GtkObject *adjustment;
 	glong summary_mode;
@@ -1226,6 +1232,14 @@ summary_properties_load (GnomePropertyObject *object)
 	gtop_properties.summary.statusbar_font = gdk_font_load
 		(gtop_properties.summary.statusbar_font_name);
 
+	if (!gtop_properties.summary.statusbar_font) {
+		g_free (gtop_properties.summary.statusbar_font_name);
+		gtop_properties.summary.statusbar_font_name =
+			g_strdup (STATUSBAR_DEFAULT_FONT);
+		gtop_properties.summary.statusbar_font = gdk_font_load
+			(gtop_properties.summary.statusbar_font_name);
+	}
+
 	max_loadavg = gnome_config_get_int
 		("gtop/procview/max_loadavg=200");
 
